# vertibird
A really, really simple Python virtualization module which interfaces directly with QEMU. Screw using libvirt.

PyPi: https://pypi.org/project/vertibird/

## Warning

This is an experimental project so far and is not yet quite ready for production use. It'll prooobably be fine if you do use it for that, but just don't blame me if anything goes wrong.

Documentation is coming really soon. For now though, you can take a look at the test script at the very end of vertibird.py, as well as some of the docstrings. It may explain some basic ways to use Vertibird.
